pub struct TriggerAuthenticationConfigMapTargetRef {
pub key: String,
pub name: String,
pub parameter: String,
}Expand description
AuthConfigMapTargetRef is used to authenticate using a reference to a config map
Fields
key: Stringname: Stringparameter: StringTrait Implementations
Sourceimpl Clone for TriggerAuthenticationConfigMapTargetRef
impl Clone for TriggerAuthenticationConfigMapTargetRef
Sourcefn clone(&self) -> TriggerAuthenticationConfigMapTargetRef
fn clone(&self) -> TriggerAuthenticationConfigMapTargetRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TriggerAuthenticationConfigMapTargetRef
impl Default for TriggerAuthenticationConfigMapTargetRef
Sourcefn default() -> TriggerAuthenticationConfigMapTargetRef
fn default() -> TriggerAuthenticationConfigMapTargetRef
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TriggerAuthenticationConfigMapTargetRef
impl<'de> Deserialize<'de> for TriggerAuthenticationConfigMapTargetRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TriggerAuthenticationConfigMapTargetRef
impl PartialEq for TriggerAuthenticationConfigMapTargetRef
Sourcefn eq(&self, other: &TriggerAuthenticationConfigMapTargetRef) -> bool
fn eq(&self, other: &TriggerAuthenticationConfigMapTargetRef) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TriggerAuthenticationConfigMapTargetRef